@@ -32,11 +32,13 @@
 #include <iomanip>
 #include <tr1/memory>
 #include <stdlib.h>
+#include <sstream>
 #include "Cache.h"
 #include "ChannelLayouts.h"
 #include "Fraction.h"
 #include "Frame.h"
 #include "Json.h"
+#include "ZmqLogger.h"
 #include <QtCore/qstring.h>
 #include <QGraphicsItem>
 #include <QGraphicsScene>
@@ -97,29 +99,11 @@ namespace openshot
 	    CriticalSection getFrameCriticalSection;
 	    CriticalSection processingCriticalSection;
 
-	    /// Debug JSON root
-	    Json::Value debug_root;
-
-		/// Append debug information as JSON
-		void AppendDebugItem(Json::Value debug_item);
-
-		/// Append debug information as JSON
-		void AppendDebugMethod(string method_name, string arg1_name, float arg1_value,
-												   string arg2_name, float arg2_value,
-												   string arg3_name, float arg3_value,
-												   string arg4_name, float arg4_value,
-												   string arg5_name, float arg5_value,
-												   string arg6_name, float arg6_value);
-
 	public:
 
 		/// Constructor for the base reader, where many things are initialized.
 	    ReaderBase();
 
-		/// Enable or disable debug output. Output will display on the standard output, and you can
-		/// optionally invoke the OutputDebugJSON() method, which will format the debug output as JSON.
-		bool debug;
-
 		/// Information about the current media file
 		ReaderInfo info;
 
@@ -160,10 +144,6 @@ namespace openshot
 
 		/// Open the reader (and start consuming resources, such as images or video files)
 		virtual void Open() = 0;
-
-		/// Output debug information as JSON
-		string OutputDebugJSON();
-
 	};
 
 }
